@@ -1,10 +1,27 @@
+from pathlib import Path
+
+from .database.config import UserConfig
+from .tools import UiTools
+
+
 class NovelSaveTemplate:
-    def __init__(self, url, username, password):
+    def __init__(self, url, username, password, directory=None):
         self.url = url
         self.username = username
         self.password = password
+        self.user = UserConfig()
 
-    def update(self):
+        # change path value
+        if directory is not None:
+            path = Path(directory).resolve().absolute()
+
+            if not path.exists():
+                path.mkdir(parents=True)
+                UiTools.print_success(f'Created dir {path}')
+
+            self.user.directory.put(str(path))
+
+    def update(self, force_cover=False):
         """
         Update novel data
 
